@@ -14,6 +14,7 @@ tcltkDialog = function(
   title = "Input",
   icon = c("info","warning","error","question"),
   type = c("message","confirm","input"),
+  parent = NULL,
   handler = NULL,
   action = NULL,
   ...
@@ -21,6 +22,21 @@ tcltkDialog = function(
 
   ## top level widnow
   dlg <- tktoplevel()
+
+  if(!is.null(parent)) {
+    parent <- getBlock(parent) ## needs to be top level window
+    curgeo <- tclvalue(tkwm.geometry(parent))
+    ## widthXheight+xpos+ypos
+    pos <- unlist(strsplit(curgeo, "\\+"))
+    sz <- unlist(strsplit(pos[1],"x"))
+    xpos = as.numeric(pos[2]); ypos=as.numeric(pos[3])
+    tkwm.geometry(dlg,paste("+",xpos+10,"+",ypos+10,sep="")) # shift
+    
+    tkwm.transient(dlg, parent) # set transient
+    tkbind(parent,"<Destroy>",function(...) tkdestroy(dlg))
+  }
+
+      
   
   ## set up icon
   icon = match.arg(icon)
@@ -33,7 +49,7 @@ tcltkDialog = function(
     )
   imageID = paste("gdialogs",as.character(runif(1)),sep="")
   tcl("image","create","photo",imageID,file=iconFile)  
-  icon = tklabel(dlg,image=imageID)
+  icon = ttklabel(dlg,image=imageID)
   
   ## set up dlg window
   tkwm.deiconify(dlg)
@@ -44,7 +60,7 @@ tcltkDialog = function(
 
   
   tkgrid(icon,row=0,column=0)
-  tkgrid(tklabel(dlg,text=message,justify="left"),
+  tkgrid(ttklabel(dlg,text=message,justify="left"),
          row=0,column=1,padx=5,pady=5, stick="w")
 
   
@@ -52,7 +68,7 @@ tcltkDialog = function(
   if(type == "input") {
     textEntryVarTcl <- tclVar(text)
     textEntryWidget <-
-      tkentry(dlg,
+      ttkentry(dlg,
               width=max(25,as.integer(1.3*nchar(text))),
               textvariable=textEntryVarTcl)
     tkgrid(textEntryWidget,column=1,stick="nw", padx=5,pady=5)
@@ -84,9 +100,9 @@ tcltkDialog = function(
     tkdestroy(dlg)
   }
   
-  gp <- tkframe(dlg)
-  OK.but     <-tkbutton(gp,text="   OK   ",command=onOK)
-  Cancel.but <-tkbutton(gp,text=" Cancel ",command=onCancel)
+  gp <- ttkframe(dlg)
+  OK.but     <-ttkbutton(gp,text="   OK   ",command=onOK)
+  Cancel.but <-ttkbutton(gp,text=" Cancel ",command=onCancel)
   
   tkgrid(gp, column=1,padx=5,pady=5)
   tkpack(OK.but,side="left")
@@ -102,7 +118,7 @@ tcltkDialog = function(
     tkbind(textEntryWidget, "<Return>", onOK)
 
   tkwait.window(dlg)
-  
+
   invisible(ReturnVal)
 }
 
@@ -115,6 +131,7 @@ setMethod(".gmessage",
                    message,
                    title = "message",
                    icon = c("info","warning","error","question"),
+                   parent = NULL,
                    handler = NULL,
                    action = NULL,
                    ...
@@ -125,6 +142,7 @@ setMethod(".gmessage",
                                title=title,
                                icon=icon,
                                type="message",
+                               parent = parent,
                                handler=handler,
                                action=action,
                                ...))
@@ -147,7 +165,8 @@ setMethod(".gconfirm",
           function(toolkit,
                    message,
                    title = "Confirm",
-                   icon = c("info", "warning", "error", "question"), 
+                   icon = c("info", "warning", "error", "question"),
+                   parent = NULL,
                    handler = NULL,
                    action = NULL,
                    ...
@@ -158,6 +177,7 @@ setMethod(".gconfirm",
                                title=title,
                                icon=icon,
                                type="confirm",
+                               parent = parent,
                                handler=handler,
                                action=action,
                                ...))
@@ -197,6 +217,7 @@ setMethod(".ginput",
                    text = "",
                    title = "Input",
                    icon = c("info","warning","error","question"),
+                   parent = NULL,
                    handler = NULL,
                    action = NULL,
                    ...
@@ -208,6 +229,7 @@ setMethod(".ginput",
                                title=title,
                                icon=icon,
                                type="input",
+                               parent = parent,
                                handler=handler,
                                action=action,
                                ...))
@@ -220,12 +242,13 @@ setMethod(".gbasicdialog",
           function(toolkit,
                    title = "Dialog",
                    widget,
+                   parent = NULL,
                    handler = NULL,
                    action = NULL,
                    ...
                    ) {
 
-            cat("This isn't implemented\n")
+            cat(gettext("gbasiddialog isn't implemented in tcltk"),"\n")
             return()
 
             
